package com.god.base.server.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.god.base.domain.Car;
import com.god.base.domain.TopicCar;
import com.god.base.domain.request.GetTopicReq;
import com.god.base.server.mapper.CarMapper;
import com.god.base.server.mapper.TopicCarMapper;
import com.god.base.server.service.TopLineService;
import com.god.common.core.exception.ServiceException;
import com.god.common.core.utils.StringUtils;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @description: 车辆上线实现
 * @Author fst
 * @date 2023/11/28 23:42
 */
@Service
@Log4j2
public class TopLineServiceImpl extends ServiceImpl<TopicCarMapper, TopicCar>  implements TopLineService {

    @Autowired
    private TopicCarMapper carMapper;

    /**
     * 车辆上线，同时返回主题
     * @param getTopicReq
     * @return
     */
    @Override
    public String getTopic(GetTopicReq getTopicReq) {
        try {
            if (StringUtils.isEmpty(getTopicReq.getVehicleVin())){
                throw  new ServiceException("车辆vin不能为空");
            }
            //根据车辆vinId查询车辆信息
            TopicCar topicCar = carMapper.selectById(getTopicReq.getVehicleVin());
            if (StringUtils.isEmpty(new TopicCar[]{topicCar})){
                throw new ServiceException("车辆信息不存在");
            }
            //把车辆状态修改为上线 1
            topicCar.setStatus(1);
            carMapper.updateById(topicCar);
            return topicCar.getTopic();
        }catch (Exception e){
            log.info(e.getMessage());
            return "god";
        }
    }
}
