package com.god.base.server.utils;

import com.god.base.domain.Car;
import com.god.base.domain.Fence;
import com.god.base.domain.request.FenceQueryRequest;
import com.god.base.server.service.CarService;
import com.god.base.server.service.FenceService;
import com.god.common.core.domain.Result;
import com.god.common.core.web.page.TableDataInfo;
import com.god.common.redis.service.RedisService;
import com.god.common.security.utils.SecurityUtils;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;

/**
 * 监控车辆围栏实时数据
 *
 * @author LouZhiSHuo
 * @Date 2023/11/29 21:31
 **/
@Component
@Log4j2
public class CarFenceMonitor {


    @Autowired
    private CarService carService;
    @Autowired
    private FenceService fenceService;
    @Autowired
    private RedisService redisService;


    @Bean
    public void getCarFencesList(){
        log.info("开始获取车辆围栏信息");

        //获取车辆信息
        Result<List<Car>> listResult = carService.carList(String.valueOf(SecurityUtils.getUserId()));
        List<Car> dataCar = listResult.getData();

        if (dataCar.size() <= 0) {
            throw new RuntimeException("查无管理车辆");
        }

        for (Car car : dataCar) {
            //单线程获取车辆围栏信息
            new Thread(() -> {
                FenceQueryRequest fenceQueryRequest = new FenceQueryRequest();

                fenceQueryRequest.setPage(1);
                fenceQueryRequest.setPageSize(100);
                fenceQueryRequest.setCarVinId(car.getCarVinId());
                //获取车辆围栏信息
                TableDataInfo<Fence> fenceTableDataInfo = fenceService.fenceListAndPage(fenceQueryRequest);
                List<Fence> rows = fenceTableDataInfo.getRows();

                if (rows.size() <= 0) {
                    throw new RuntimeException("该车辆未绑定围栏");
                }

                //围栏对象集合
                List<Fence> locationList = new ArrayList<>();

                for (Fence row : rows) {
                    locationList.add(row);
                }

                //存储redis
                redisService.setCacheList(car.getCarVinId()+"fence",locationList);

            }).start();
        }





    }
}
